package card

import (
	"encoding/json"
	"errors"
	"net/http"
	"spaceofcheng/services/controllers"
	cardModel "spaceofcheng/services/models/card"
	"spaceofcheng/services/service/card"
	"spaceofcheng/services/utils"
	"strings"
)

// CardController 商品
type CardController struct {
	serv *card.CardServ
	controllers.BaseController
}

// Constructor 初始化 Controller
// @Title Constructor
// @Description 初始化 Controller, 系统自动调用
func (c *CardController) Constructor() {
	c.serv = card.NewCardServ(c.Context)
}

// ListByCase 获取卡列表
func (c *CardController) ListByCase() {
	caseid := c.GetString("caseid")
	page, _ := c.GetInt("page")
	pagesize, _ := c.GetInt("pagesize")
	if page < 0 {
		page = 1
	}

	if pagesize <= 0 {
		pagesize = 10
	}

	list, total, err := c.serv.GetCardList(caseid, page, pagesize)
	if err != nil {
		c.ResponseError(err)
	}

	c.ResponseJSON(map[string]interface{}{
		"list":     list,
		"page":     page,
		"pagesize": pagesize,
		"pagenum":  total,
	})
}

// GetCardByIDForAdmin 获取卡
// 管理端
func (c *CardController) GetCardByIDForAdmin() {
	id := c.GetString(":id")
	if id == "" {
		c.ResponseError(errors.New("未指定卡"))
	}

	card, err := c.serv.GetCardByIDWithCheck(id)
	if err != nil {
		c.ResponseError(err)
	}

	c.ResponseJSON(map[string]interface{}{
		"Card": card,
	})
}

// GetCardByID 获取卡
// 微信端
func (c *CardController) GetCardByID() {
	id := c.GetString(":id")
	if id == "" {
		c.ResponseError(errors.New("未指定卡"))
	}

	card, err := c.serv.GetCardByID(id)
	if err != nil {
		c.ResponseError(err)
	}

	c.ResponseJSON(map[string]interface{}{
		"Card": card,
	})
}

// GetMyCard 获取我的卡券
// 微信端
func (c *CardController) GetMyCard() {

}

// SaveCard 保存卡
func (c *CardController) SaveCard() {
	jsnStr := c.GetString("info")
	if jsnStr == "" {
		c.ResponseError(errors.New("未接收到保存内容"))
	}

	card := cardModel.CardInfo{}

	if err := json.Unmarshal([]byte(jsnStr), &card); err != nil {
		utils.LogError("接收卡信息失败: " + err.Error())
		c.ResponseError(errors.New("接收参数失败"), http.StatusInternalServerError)
	}

	// TODO
	// 校验各字段不能为空

	// 入库
	card.CardId = ""
	if err := c.serv.SaveCard(&card); err != nil {
		c.ResponseError(err)
	}

	c.ResponseJSON(map[string]interface{}{
		"Card": card,
	})
}

// UpdateCard 更新卡
func (c *CardController) UpdateCard() {
	jsnStr := c.GetString("info")
	if jsnStr == "" {
		c.ResponseError(errors.New("未接收到更新内容"))
	}

	id := c.GetString(":id")
	if id == "" {
		c.ResponseError(errors.New("未指定卡"))
	}

	card := cardModel.CardInfo{}

	if err := json.Unmarshal([]byte(jsnStr), &card); err != nil {
		utils.LogError("接收卡信息失败: " + err.Error())
		c.ResponseError(errors.New("接收参数失败"), http.StatusInternalServerError)
	}

	// TODO
	// 校验各字段不能为空

	// 入库
	card.CardId = id
	if err := c.serv.UpdateCard(&card); err != nil {
		c.ResponseError(err)
	}

	c.ResponseJSON(map[string]interface{}{
		"Card": card,
	})
}

// GiveCard 赠送卡
func (c *CardController) GiveCard() {
	id := c.GetString(":id")
	if id == "" {
		c.ResponseError(errors.New("未指定卡"))
	}

	uids := c.GetString(":users")
	if uids == "" {
		c.ResponseError(errors.New("未指定赠送人"))
	}

	err := c.serv.GiveCard(id, strings.Split(uids, ","))
	if err != nil {
		c.ResponseError(err)
	}

	c.ResponseJSON("ok")
}
