package gymcard

import (
	"spaceofcheng/services/controllers"
	gym "spaceofcheng/services/models/gymcard"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/service/gymcard"
)

// GymcardController 信息
type GymcardController struct {
	dao *gymcard.GymcardServ
	controllers.BaseController
}

// Constructor 初始化 Controller
// @Title Constructor
// @Description 初始化 Controller, 系统自动调用
func (c *GymcardController) Constructor() {
	c.dao = gymcard.NewGymcardServ(c.Context)
}

// GetGymcardList 后台获取游泳健身卡列表
func (c *GymcardController) GetGymcardList() {
	caseIDs := c.GetString("caseid")
	if caseIDs == "" {
		cases := c.Context.Get("cases").([]model.SysUserCase)
		caseIDs = c.GetCaseIDs(cases)
	}
	page, _ := c.GetInt("page")
	pageSize, _ := c.GetInt("pagesize")
	list, err := c.dao.GetGymcardList(caseIDs, page, pageSize)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(list)
}

// GetGymcardListByCustomerId 根据客户id获取C端客户所有的健身卡
func (c *GymcardController) GetGymcardListByCustomerId() {
	page, _ := c.GetInt("page")
	pageSize, _ := c.GetInt("pagesize")
	list, err := c.dao.GetCustomerGymBycustomerId(page, pageSize)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(list)
}

// GetGymcardDetailbyId 根据游泳健身卡ID获取游泳健身卡详情
func (c *GymcardController) GetGymcardDetailbyId() {
	id := c.GetString(":gymcardId")
	gymcard, err := c.dao.GetGymcardDetailById(id)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(gymcard)
}

// GetCustomerGymDetailById 根据客户健身卡ID获取客户健身卡详情
func (c *GymcardController) GetCustomerGymDetailById() {
	id := c.GetString(":customerGymId")
	customerGym, err := c.dao.GetCustomerGymDetailById(id)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(customerGym)
}

// GetCustomerGymByPhone 根据客户手机获取客户可用的游泳健身卡
func (c *GymcardController) GetCustomerGymByPhone() {
	phone := c.GetString(":phone")
	customerGym, err := c.dao.GetCustomerGymByPhone(phone)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(customerGym)
}

// SaveGymcard 保存游泳健身卡
func (c *GymcardController) SaveGymcard() {
	gymCard := gym.Gymcard{}
	if err := c.ParseForm(&gymCard); err != nil {
		c.ResponseError(err)
	}
	newGymcard, err := c.dao.SaveGymcard(gymCard)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(newGymcard)
}

// SendGymToCustomer 客户领卡
func (c *GymcardController) SendGymToCustomer() {
	gymcardId := c.GetString(":gymcardId")
	sysuserId := c.GetString(":sysuserId")
	customerGym, err := c.dao.SendGymCardToUser(gymcardId, sysuserId)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(customerGym)
}

// VerifyCustomerGymcard 核销客户健身卡
func (c *GymcardController) VerifyCustomerGymcard() {
	cases := c.Context.Get("cases").([]model.SysUserCase)
	caseids := c.GetCaseIDs(cases)
	customerGymId := c.GetString(":customerGymId")
	err := c.dao.UpdateCustomerGym(customerGymId, caseids)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON("核销成功")
}
