package statistics

import (
	"spaceofcheng/services/models"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/utils"
	"strconv"
	"strings"

	"github.com/go-xorm/xorm"
)

// StatisticsDAO 当前数据库操作对象
type StatisticsDAO struct {
	ctx *utils.Context
	db  *xorm.Session
}

// NewStatisticsDAO New Inst
func NewStatisticsDAO(ctx *utils.Context) *StatisticsDAO {
	return &StatisticsDAO{
		ctx: ctx,
		db:  ctx.DB,
	}
}

// GetCustomerCount 获取会员总数
func (m *StatisticsDAO) GetCustomerCount(orgid string) (int, error) {
	var customers []model.TaCustomer
	err := m.db.Where("org_id=?", orgid).And("status>" + strconv.Itoa(models.STATUS_DEL)).Find(&customers)
	if err != nil {
		return 0, err
	}
	return len(customers), nil
}

// GetCourseOrderCount 获取课程预约总量
func (m *StatisticsDAO) GetCourseOrderCount(caseids string) (int64, error) {
	var courses = new(model.TaCustomerCourse)
	total, err := m.db.Where("case_id in ('"+strings.Replace(caseids, ",", "','", -1)+"')").And("status>"+strconv.Itoa(models.STATUS_DEL)).SumInt(courses, "course_num")
	if err != nil {
		return 0, err
	}
	return total, nil
}

// GetGoodsOrderCount 获取商品下单总量
func (m *StatisticsDAO) GetGoodsOrderCount(caseids string) (int64, error) {
	var goodsorder = new(model.TaGoodsOrders)
	total, err := m.db.Where("case_id in ('"+strings.Replace(caseids, ",", "','", -1)+"')").And("status>"+strconv.Itoa(models.STATUS_DEL)).SumInt(goodsorder, "orders_num")
	if err != nil {
		return 0, err
	}
	return total, nil
}

// GetCustomerCountByDate 根据时间获取新增会员数量
func (m *StatisticsDAO) GetCustomerCountByDate(caseids, begindate, enddate string) (int, error) {
	var customers []model.TaCustomer
	err := m.db.Where("recommend_case in ('" + strings.Replace(caseids, ",", "','", -1) + "')").And("binding_date BETWEEN '" + begindate + "' AND '" + enddate + "'").And("status>" + strconv.Itoa(models.STATUS_DEL)).Find(&customers)
	if err != nil {
		return 0, err
	}
	return len(customers), nil
}

// GetCoursesCountByDate 根据时间获取课程数
func (m *StatisticsDAO) GetCoursesCountByDate(caseids, begindate, enddate string) (int, error) {
	var details []model.TaCourseDetail
	sql := `select a.* from ta_course_detail a inner join ta_course b on a.course_id=b.course_id where b.status=` + strconv.Itoa(models.STATUS_NORMAL)
	sql += ` and a.case_id in ('` + strings.Replace(caseids, ",", "','", -1) + `') and a.begin_date  BETWEEN '` + begindate + `' AND '` + enddate + `'`
	err := m.db.Sql(sql).Find(&details)
	if err != nil {
		return 0, err
	}
	return len(details), nil
}

// GetCourseOrderCountByDate 根据时间获取课程预约数量
func (m *StatisticsDAO) GetCourseOrderCountByDate(caseids, begindate, enddate string) (int64, error) {
	courses := new(model.TaCustomerCourse)
	total, err := m.db.Where("case_id in ('"+strings.Replace(caseids, ",", "','", -1)+"')").And("status>"+strconv.Itoa(models.STATUS_DEL)).And("create_date BETWEEN '"+begindate+"' AND '"+enddate+"'").SumInt(courses, "course_num")
	if err != nil {
		return 0, err
	}
	return total, nil
}

// GetCourseVerifyCountByDate 根据时间获取课程核销人数
func (m *StatisticsDAO) GetCourseVerifyCountByDate(caseids, begindate, enddate string) ([]model.TaCourseVerifcation, error) {
	var courseVerify []model.TaCourseVerifcation
	err := m.db.Where("case_id in ('" + strings.Replace(caseids, ",", "','", -1) + "')").And("status>" + strconv.Itoa(models.STATUS_DEL)).And("create_date BETWEEN '" + begindate + "' AND '" + enddate + "'").Find(&courseVerify)
	return courseVerify, err
}

// GetGymVerifyCountByDate 根据时间获取健身卡核销人数
func (m *StatisticsDAO) GetGymVerifyCountByDate(caseids, begindate, enddate string) ([]model.TaGymCardUsage, error) {
	var gyms []model.TaGymCardUsage
	err := m.db.Where("status>" + strconv.Itoa(models.STATUS_DEL)).And("use_case_id in ('" + strings.Replace(caseids, ",", "','", -1) + "')").And("create_date BETWEEN '" + begindate + "' AND '" + enddate + "'").Find(&gyms)
	return gyms, err
}

// GetGoodsOrderCountByDate 根据时间获取商品下单
func (m *StatisticsDAO) GetGoodsOrderCountByDate(caseids, begindate, enddate string) ([]model.TaGoodsOrders, error) {
	var goodsorder []model.TaGoodsOrders
	err := m.db.Where("case_id in ('" + strings.Replace(caseids, ",", "','", -1) + "')").And("create_date BETWEEN '" + begindate + "' AND '" + enddate + "'").And("status>" + strconv.Itoa(models.STATUS_DEL)).Find(&goodsorder)
	return goodsorder, err
}

//
